<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :isShowHide="true"
        :prelang="prelang"
        :options="options"
        :bottomOffset="125"
        :ajaxFun="ajaxFun"
        ref="unitworkfactorTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
      <!-- 批量修改定额 -->
      <quota-form
        v-if="updateQuotaVisible"
        ref="updateQuota"
        @refreshDataList="getData"
      ></quota-form>
    </basic-container>
  </div>
</template>

<script>
import { fetchList, delObj } from '@/api/accounting/unitwork'
import TableForm from './unitworkfactor-form'
import QuotaForm from '@/views/accounting/unitworkfactor/updateQuota-form.vue'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { remote } from '../../../api/admin/dict'

export default {
  data() {
    return {
      ajaxFun: fetchList,
      addOrUpdateVisible: false,
      updateQuotaVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'unitworkfactor',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 工序
          {
            minWidth: '30',
            prop: 'operationName',
            label: '工序',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 机台
          {
            minWidth: '120',
            prop: 'workstationNo',
            label: '机台',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件
          {
            minWidth: '120',
            prop: 'partNo',
            label: '零件',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 单位工时系数
          {
            minWidth: '120',
            prop: 'unitWorkFactor',
            label: '单位工时系数',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 定额
          {
            minWidth: '120',
            prop: 'quota',
            label: '定额',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          },
          {
            text: '批量修改定额',
            type: 'primary',
            fun: this.updateQuotaHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      }
    }
  },
  components: {
    TableForm,
    QuotaForm,
    ttable
  },
  created() {},
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.unitworkfactorTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 批量修改定额
    updateQuotaHandle() {
      this.updateQuotaVisible = true
      if (this.multipleSelection.length > 0) {
        const list = this.multipleSelection
        const ids = list.map((ele) => {
          return ele.id
        })
        this.$nextTick(() => {
          this.$refs.updateQuota.init(ids)
        })
      } else {
        this.$message.error('请选择需要修改的定额')
      }
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认零件为:' + row.partNo, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    }
  }
}
</script>
